<template>
  <div class="page">
    <div class="info">
      <div class="detail">
        <span class="label">
          <avatar :size="40">
            <div class="per-name">
              {{ employee.nameSlice }}
            </div>
          </avatar>
        </span>
        <span class="value">&nbsp;{{ employee.name }}（{{ employee.dutyStatusText }}）</span>
      </div>

      <div class="detail">
        <span class="label">所属公司：</span>
        <span class="value value-link" @click="toCompany">{{ employee.companyName }}</span>
      </div>
      <div class="detail">
        <span class="label">所属{{ employee.isTemporarySecurity ? "岗点" : employee.isSecurity ? "驻勤点" : "社区警务" }}：</span>
        <span class="value value-link" @click="toStation">{{ employee.securityStationName }}</span>
      </div>
      <div class="detail">
        <span class="label">证件号码：</span>
        <span v-if="!idVisible" class="value">{{ employee.idCardNoHide }}</span>
        <span v-if="idVisible" class="value">{{ employee.idCardNo }}</span>
        <span class="visible" @click="idVisible = !idVisible">{{ idVisibleName }}</span>
      </div>
      <div class="detail">
        <span class="label">联系方式：</span>
        <span v-if="!concatVisible" class="value">{{ employee.contactHide }}</span>
        <span v-if="concatVisible" class="value">{{ employee.contact }}</span>
        <span class="visible" @click="concatVisible = !concatVisible">{{ contactVisibleName }}</span>
      </div>
      <div class="detail">
        <span class="label">实名认证：</span>
        <span class="value">{{ employee.authenticatedStatusText }}</span>
      </div>
      <div class="detail">
        <span class="label">持证情况：</span>
        <span class="value">{{ employee.certificateSituation }}</span>
      </div>
    </div>
  </div>
</template>

<script>
import { getEmployeeDetail } from "@/api/employee-controller";
import { textSlice } from "@/api/common";
import Avatar from "@components/avatar.vue";
export default {
  name: "EmployeeInfo",
  components: {
    Avatar,
  },
  data() {
    return {
      employee: {},
      idVisible: false,
      concatVisible: false,
    };
  },
  computed: {
    queryId() {
      return this.$route.query.queryId;
    },
    idVisibleName() {
      return this.idVisible ? "隐藏" : "显示";
    },
    contactVisibleName() {
      return this.concatVisible ? "隐藏" : "显示";
    },
  },
  methods: {
    toCompany() {
      this.$router.push({
        path: "/companyInfo",
        query: {
          queryId: this.employee.organizationId,
        },
      });
    },
    toStation() {
      const queryId = this.employee.securityStationId;
      this.$router.push({
        path: "/stationInfo",
        query: {
          queryId,
        },
      });
    },
    parseStringToStar(str) {
      return "**************";
      // return str.length > 2 ? str.substr(0, 2) + new Array(str.length - 2).join("*") + str.substr(-2) : str;
    },
    getData() {
      // 聚焦并弹框
      getEmployeeDetail(this.queryId)
        .then((employeeDetail) => {
          console.log("onClickEmployee", employeeDetail);
          const { name, idCardNo, contact, companyName, securityStationName, resourceTypes } = employeeDetail;

          this.employee = {
            ...{
              nameSlice: name.slice(-2),
              idCardNoHide: this.parseStringToStar(idCardNo),
              contactHide: this.parseStringToStar(contact),
              companyNameSlice: textSlice(companyName),
              securityStationNameSlice: textSlice(securityStationName),
              isSecurity: resourceTypes.includes("Security"),
              isTemporarySecurity: resourceTypes.includes("Security") && resourceTypes.includes("TemporarySecurity"),
            },
            ...employeeDetail,
          };
        })
        .catch((err) => {
          console.log(err);
        });
    },
  },
  created() {
    this.getData();
  },
};
</script>

<style scoped lang="less">
.page {
  .info {
    width: 100%;
    padding: 12px 20px;

    .per-name {
      height: 40px;
      width: 40px;
      background: #0e71ff;
      color: #fff;
      font-size: 12px;
      display: flex;
      align-items: center;
      justify-content: center;
    }

    .detail {
      width: 100%;
      display: flex;
      align-items: center;
      margin-bottom: 10px;
      &:last-child {
        margin-bottom: 0;
      }
      .label {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #909399;
      }

      .value {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #303133;
        &-link {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #0f71ff;
          text-decoration: underline;
        }
      }
      .visible {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #0f71ff;
        margin-left: 2px;
      }
    }
  }
}
</style>
